# Changelog

### 0.1.0

* First stable version with tax modelling, UBI reforms, and some benefits modelling.
* Details:
  - Income Tax, National Insurance, Capital Gains Tax.
  - All benefits are at least taken from survey reporting (can be switched on-off).
  - Child Benefit is modelled, others such as Income Support, JSA (both types), Tax Credits can be simulated/reformed but require more reviewing in how to account for discrepancies caused by take-up rates.
  - Four budget-neutral UBI reforms are implemented.
  - 15 test cases (unit and integration) testing benefits and taxes.
  - Simulation helper tools.